Example notebooks
=================


* [Example usage of the OApackage](example_oapackage.ipynb)
* [List of example designs contained in the package](example_designs.ipynb)
* [Conference isomorphisms](conference_design_isomorphism.ipynb)
* [Generate orthogonal arrays](example_design_generation.ipynb)
* [Write arrays to disk, or read from disk](example_oa_files.ipynb)
* [Reduction of graphs to normal form using Nauty](example_nauty.ipynb)
* [Calculate a Pareto optimal set of elements](example_pareto.ipynb)

